--[[
--Colorblind Teamplay v0.2
--By Romain Brunetaud (Vlad Tepes)
--Adds lots of configuration options for team play
--]]

--[[  CONFIGURATION AREA  ]]--

FULL_BODY_TEAM_COLOR = true
--if true, will change the player shirt color to match their pants (team color)

FRIENDLY_FIRE = true 
--if true, friendly fire is on

FRIENDLY_FIRE_MIRROR = true
--if true, the damage done by friendly fire is also inflicted to the aggressor

FRIENDLY_FIRE_RATIO = 0.5
--ratio of damage inflicted to teammates compared to enemies
--the amount of damage is rounded down for victim and rounded up for aggressor
--(if mirror turned on) so that aggressor will die before its victim


SOUND_ACTIVATED = true
-- When activated, randomly plays sounds on friendly fire
-- the probability a sound is played is linked to the amount of damage done

SOUND_SORRY	= "bob apology"
-- Apology sound (aggressor sound)

SOUND_WATCHIT	= "bob angry"
-- Watch it sound (victim sound)

SOUND_DAMAGE_FACTOR = 100
-- Sets the damage factor for randomized sound play
-- on friendly damage, the probability a sound plays is 
-- friendly_damage_amount / SOUND_DAMAGE_FACTOR


--[[ END OF CONFIGURATION ]]--
Triggers = {}
function Triggers.init()
	if FULL_BODY_TEAM_COLOR then
		for p in Players() do
			p.color = p.team
		end
	end

	if not FRIENDLY_FIRE then
		FRIENDLY_FIRE_RATIO = 0
	end
end


function Triggers.player_damaged(victim, aggressor_player, aggressor_monster, damage_type, damage_amount, projectile)
	if aggressor_player ~= nil and aggressor_player ~= victim then --Check if damage done by another player
		if victim.team == aggressor_player.team then --Check if same team damage
			
			-- give the victim some life back
			victim.life = victim.life + math.ceil(damage_amount * (1-FRIENDLY_FIRE_RATIO))
			
			-- damage aggressor if mirror mode active
			if FRIENDLY_FIRE_MIRROR then
				aggressor_player:damage(math.ceil(damage_amount * FRIENDLY_FIRE_RATIO))
			end

			-- play sounds
			if SOUND_ACTIVATED then
				if Game.random(SOUND_DAMAGE_FACTOR) < damage_amount then
					victim.monster:play_sound(SOUND_WATCHIT)
				end

				if Game.random(SOUND_DAMAGE_FACTOR) < damage_amount then
					aggressor_player.monster:play_sound(SOUND_SORRY)
				end
			end
		end
	end
end